/* **********************************************************
 * Copyright (C) 1998-2000 VMware, Inc.
 * All Rights Reserved
 * **********************************************************/

#ifndef __VMNETINT_H__
#define __VMNETINT_H__


#define INCLUDE_ALLOW_MODULE
#include "includeCheck.h"
#include "driver-config.h"

#ifndef KERNEL_VERSION
# define KERNEL_VERSION(a,b,c) (((a) << 16) + ((b) << 8) + (c))
#endif



/*
 * Hide all kernel compatibility stuff in those macros
 */


#if LINUX_VERSION_CODE < KERNEL_VERSION(2,3,18)
#   if LINUX_VERSION_CODE < KERNEL_VERSION(2,1,30)
       typedef struct {} spinlock_t;
#      define spin_lock_init(lock)
#      define spin_lock_init(lock)
#      define spin_lock(lock)
#      define spin_lock_irqsave(lock, flags)
#      define spin_unlock(lock)
#      define spin_unlock_irqrestore(lock, flags)
#   else
#      include <asm/spinlock.h>
#   endif
#else
#   include <linux/spinlock.h>
#endif


#ifdef KERNEL_2_1
#   define compat_fop_set_poll(_pFop, _pFunc) do { \
   (_pFop)->poll = (_pFunc);                       \
} while (0)
#else
#   define compat_fop_set_poll(_pFop, _pFunc) do { \
   (_pFop)->select = (_pFunc);                     \
} while (0)
#endif


/* Appeared in 2.3 kernels, and was then back ported to 2.2.18 --hpreg */
#ifndef DECLARE_WAITQUEUE
#   define DECLARE_WAITQUEUE(name, task) struct wait_queue name = {task, NULL,}
#endif


#ifdef KERNEL_2_4_0
#   define compat_fop_set_owner(_pFop) do { \
   (_pFop)->owner = THIS_MODULE;            \
} while (0)
#   define compat_mod_inc_refcount
#   define compat_mod_dec_refcount
#else
#   define compat_fop_set_owner(_pFop)
#   define compat_mod_inc_refcount do { \
   MOD_INC_USE_COUNT;                   \
} while (0)
#   define compat_mod_dec_refcount do { \
   MOD_DEC_USE_COUNT;                   \
} while (0)
#endif


#ifndef KERNEL_2_1
#   define net_device_stats enet_statistics
#endif


#if LINUX_VERSION_CODE < KERNEL_VERSION(2,5,2)
#  define MINOR_PORTION(x) MINOR(x)
#  define MAJOR_PORTION(x) MAJOR(x)
#else
#  define MINOR_PORTION(x) minor(x)
#  define MAJOR_PORTION(x) major(x)
#endif


#endif /* __VMNETINT_H__ */
